% Copyright (c) 2011, Ludwig Institute for Cancer Research.
% All rights reserved.
% Author: Armand Valsesia <armand.valsesia@licr.org>
%
% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions
% are met:
%     * Redistributions of source code must retain the above copyright
%       notice, this list of conditions and the following disclaimer.
%     * Redistributions in binary form must reproduce the above
%       copyright notice, this list of conditions and the following
%       disclaimer in the documentation and/or other materials
%       provided with the distribution.
%     * Neither the name of the <organization> nor the
%       names of its contributors may be used to endorse or promote
%       products derived from this software without specific prior
%       written permission.
%
% THIS SOFTWARE IS PROVIDED BY GRL ``AS IS'' AND ANY EXPRESS OR
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
% WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
% ARE DISCLAIMED.  IN NO EVENT SHALL GRL BE LIABLE FOR ANY DIRECT,
% INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
% (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
% SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
% HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
% ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
% OF THE POSSIBILITY OF SUCH DAMAGE.
%
% convert input file (fn) to a more convenient .mat file
function [chr pos data samples]=convert_tab2mat(fn, delim,output)

if nargin < 2
    delim='\t';
end
if nargin < 3
    output=[fn '.mat'];
end
try
    load( output);
    fprintf('Reloaded data from %s\n',[fn '.mat'])
catch
    fprintf('Converting %s to %s\n',fn,[fn '.mat'])
    nn = get_col_num(fn);
    fid = fopen(fn);
    C0 = textscan(fid,repmat('%s',1,nn),1,'delimiter',delim); % get header
    C = textscan(fid,['%s' repmat('%n',1,nn-1)],'delimiter',delim); % get data, assume 1st column contains string
    fclose(fid);


    samples = cell(nn,1);
    for i=1:nn
        samples{i} = C0{i}{1};
    end
    samples = samples(3:end);

    % convert chr to numeric, X will become 23, Y : 24
    % and Mitochondrial : 0
    chr=regexprep( C{1}, 'chr','','ignorecase',1);
    chr=regexprep( chr, 'X','23','ignorecase',1);
    chr=regexprep( chr, 'Y','24','ignorecase',1);
    chr=regexprep( chr, 'M','0','ignorecase',1);
    chr=regexprep( chr, 'Mt','0','ignorecase',1);

    chr=str2double(chr);
    pos=C{2};
    data=zeros( length(C{1}), nn-2)*NaN;
    for i=3:nn
        data(:,i-2)=C{i} ;
    end

    clear C0 C;

    save(output, 'chr','pos','data','samples');

end
