% Copyright (c) 2011, Ludwig Institute for Cancer Research.
% All rights reserved.
% Author: Armand Valsesia <armand.valsesia@licr.org>
%
% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions
% are met:
%     * Redistributions of source code must retain the above copyright
%       notice, this list of conditions and the following disclaimer.
%     * Redistributions in binary form must reproduce the above
%       copyright notice, this list of conditions and the following
%       disclaimer in the documentation and/or other materials
%       provided with the distribution.
%     * Neither the name of the <organization> nor the
%       names of its contributors may be used to endorse or promote
%       products derived from this software without specific prior
%       written permission.
%
% THIS SOFTWARE IS PROVIDED BY GRL ``AS IS'' AND ANY EXPRESS OR
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
% WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
% ARE DISCLAIMED.  IN NO EVENT SHALL GRL BE LIABLE FOR ANY DIRECT,
% INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
% (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
% SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
% HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
% ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
% OF THE POSSIBILITY OF SUCH DAMAGE.
%
%
% function to find monormorphic regions and create genomic windows going
% from half of region i to half region i+1
%
% argins :
%   - input : master input file (as formatted by convert_tab2mat)
%   - output : where to save results
%   - W : length of monomorphic regions (in Mb)
%   - simple_merge_dir : directory containing results from simple merge are
%   - chr_list : chromsomes to do (there should be 1 'simple_merge' file /  chr
%
% return R :  a matrix where columns are chr start end
function R=segment_genome(input,output,W,simple_merge_dir,chr_list)
if nargin <5
    error('Segment_genome missing argins')
end
try

    load(output);
    disp(['reloading ' output]);

catch
    R=[];
    load(input,'pos','chr');
    POS=pos;
    CHR=chr;
    clear chr pos;
    disp('searching for interesting regions');
    for ix=1:length(chr_list) %iterate chromosomes

        chr=chr_list(ix);
        pos=POS(CHR==chr);
        load([simple_merge_dir,'chr',num2str(chr),'.mat' ],'regions');

        regions_length = ( regions(:,4)-regions(:,3)+1)/1e6;  % in Mb


        % find monormophic regions, with length > W
        monoregions = find(regions(:,6) == 0 & regions_length >= W );


        if( ~isempty(monoregions ))
            % regions found, create interval as going from 1 to half 1st
            % region, then from half 1st region to half 2nd ...
            % finish with half last region to end chr

            % calc mid points
            mid= mean( regions(monoregions,3:4),2) ;

            % create regions min(SNP.pos):mid(1) , mid(1)+1:mid(2) ...
            % mid(end):max(SNP.pos)

            R=[ R;[ repmat(chr,length(mid)+1,1), [ min(pos) ;mid], [ mid+1 ; max(pos) ] ]];


        else
            % no region found, use the whole chr
            R=[ R;[ chr, min(pos),max(pos)] ];
        end
    end

    save(output , 'R');
end
